var crypto = require('crypto');
var os = require('os');
var path = require('path');
var mkdirp = require('mkdirp');
var fs = require('fs');

function insecureHash(data) {

    if ((!data) || (typeof data !== 'string'))
        return;

    var hash = crypto.createHash('sha1').update(data).digest('hex');
    return hash.toUpperCase();
}

function secureHash(data) {

    return insecureHash([insecureHash(data), data].join(''));
}

function makeCertName(productId, cdbNumber, machineName) {

    return [
        insecureHash(productId),
        insecureHash(cdbNumber),
        insecureHash(machineName),
        '.dat'
    ].join('');
}

function connectionStringToObj(connectionString) {

    var result = {};
    if (connectionString)
        connectionString.split(';').forEach(function (keyValueString) {
            var kvp = keyValueString.split('=');
            kvp[1] && (result[kvp[0]] = kvp[1]);
        });

    return result;
}

function buildFileName(productId, cdbNumber, options) {

    options = options || {};

    var baseFolder = options['apiDataFolder'] || 'C:/ProgramData';
    var machineName = options['machineName'] || os.hostname().toUpperCase();

    var certFolderName = secureHash(productId);

    return path.join(
        baseFolder,
        'PatientApi',
        certFolderName,
        makeCertName(productId, cdbNumber, machineName));
}

function FileNameFromConnectionString(connectionString, options){

    var orgInfo = connectionStringToObj(connectionString);
    if (orgInfo['productId']) {
        return buildFileName(orgInfo['productId'], orgInfo['organisation'], options);
    }
}

function createEmptyFile(filename){

    var dirPath = path.dirname(filename);
    mkdirp.mkdirP.sync(dirPath);
    fs.closeSync(fs.openSync(filename, 'a'));
}

var hash = {};

exports.buildFileName = buildFileName;

exports.FileNameFromConnectionString = FileNameFromConnectionString;

exports.createApiCertFile = function(connectionString, options) {

    if (hash[connectionString] === true)
        return;

    var filename = FileNameFromConnectionString(connectionString, options);
    if (filename)
        createEmptyFile(filename);

    hash[connectionString] = true;
};

